@@ -7,14 +7,13 @@ import termios
 import tty
 from select import select
 import pwd
-import nis
 import time
 import re
 from shutil import copy2
 from email.utils import formatdate
 from enum import Enum
 
-__version__ = '2.202301'
+__version__ = '2.202302'
 __dhlib__ = '/usr/share/debhelper/dh_make'
 policy_version = '4.6.2'
 
@@ -399,14 +398,6 @@ def get_username():
         if username:
             return username
 
-    # NIS/ypmatch
-    try:
-        username = nis.match(logname, 'passwd.byname').split(':')[4]
-        if username:
-            return username
-    except nis.error:
-        pass
-
     # TODO ldap?
 
     # all failed
